@@ -1,12 +1,7 @@
 package Git::Class::Role::Execute;
 
-use Any::Moose '::Role'; with qw/
-  Git::Class::Role::Error
-  Git::Class::Role::Cwd
-/;
+use Any::Moose '::Role'; with 'Git::Class::Role::Error';
 use Capture::Tiny qw(capture tee);
-use Scope::Guard ();
-use Cwd ();
 
 sub _execute {
   my ($self, @args) = @_;
@@ -17,14 +12,15 @@ sub _execute {
     print STDERR join ' ', @args, "\n";
   }
 
+  unless (defined wantarray) {
+    my $rc = system(join ' ', @args);
+    $self->_error($rc) if $rc;
+    return;
+  }
+
   my ($out, $err) = do {
     local *capture = *tee if $self->is_verbose;
-    capture {
-      my $cwd = Cwd::cwd();
-      my $guard = Scope::Guard::guard { chdir $cwd };
-      chdir $self->_cwd if $self->_cwd;
-      system(@args)
-    };
+    capture { system(join ' ', @args) };
   };
 
   $self->_error($err) if $err;
